@@ -1,7 +1,7 @@
 """Database file handling.
 """
 
-# pylint: disable= invalid-name, bad-whitespace
+# pylint: disable= invalid-name
 
 import sys
 import os.path
@@ -16,7 +16,7 @@ if __name__ == "__main__":
 import sumolib.ModuleSpec
 import sumolib.JSON
 
-__version__="4.1.3" #VERSION#
+__version__="4.1.4" #VERSION#
 
 assert __version__==sumolib.ModuleSpec.__version__
 assert __version__==sumolib.JSON.__version__
@@ -124,8 +124,8 @@ class DB(sumolib.JSON.Container):
         new_builds= set()
         for b in other.iter_builds():
             if self.has_build_tag(b):
-                warn("warning: buildtag '%s' found in both build databases, "
-                     "the later one will be ignored.")
+                warn(("warning: buildtag '%s' found in both build databases, "
+                      "the later one will be ignored.") % b)
                 continue
             # note: this is *NOT* a deepcopy, just the reference is copied:
             d[b]= od[b]
@@ -450,7 +450,7 @@ class BuildCache(sumolib.JSON.Container):
     """
     def __init__(self, dict_= None, use_lock= True, lock_timeout= None):
         """create the object."""
-        super(BuildCache, self).__init__(dict_, use_lock, lock_timeout)
+        super().__init__(dict_, use_lock, lock_timeout)
     def add_dependency(self, modulename, versionname,
                        dep_name, dep_version, state):
         """add a single dependency with a state."""
